==> vcaml-v0.15.0.tar.gz: vcaml-v0.15.0/example/hello_world/test/test_hello_world.ml <==
open! Core
open! Async
open! Vcaml
open! Vcaml_hello_world

let%expect_test "plugin echoes a message" =
  let%map screen =
    Vcaml_test.with_ui_client (fun client ui ->
      let open Deferred.Or_error.Let_syntax in
      let%bind () = Hello_world.For_testing.echo_hello_world client in
      Vcaml_test.get_screen_contents [%here] ui)
  in
  print_endline screen;
  [%expect
    {|
    ╭────────────────────────────────────────────────────────────────────────────────╮
    │                                                                                │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │[No Name]                                                     0,0-1          All│
    │Hello, world!                                                                   │
    ╰────────────────────────────────────────────────────────────────────────────────╯ |}]
;;

==> vcaml-v0.16.0.tar.gz: vcaml-v0.16.0/example/hello_world/test/test_hello_world.ml <==
open! Core
open Async
open! Vcaml
open Vcaml_hello_world
open Vcaml_test_helpers

let%expect_test "plugin echoes a message" =
  let%map screen =
    with_ui_client (fun client ui ->
      let open Deferred.Or_error.Let_syntax in
      let%bind () = Hello_world.For_testing.echo_hello_world client in
      get_screen_contents [%here] ui)
  in
  print_endline screen;
  [%expect
    {|
    ╭────────────────────────────────────────────────────────────────────────────────╮
    │                                                                                │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │~                                                                               │
    │[No Name]                                                     0,0-1          All│
    │Hello, world!                                                                   │
    ╰────────────────────────────────────────────────────────────────────────────────╯ |}]
;;
